#[repr(u64)]pub enum Interest {
Show 34 variants
Established = 1,
Any = 2,
Access = 4,
AccessOpen = 8,
AccessClose = 16,
AccessRead = 32,
AccessOther = 64,
Create = 128,
CreateFile = 256,
CreateFolder = 512,
CreateOther = 1_024,
Modify = 2_048,
ModifyData = 4_096,
ModifyDataSize = 8_192,
ModifyDataContent = 16_384,
ModifyDataOther = 32_768,
ModifyMetadata = 65_536,
ModifyMetadataAccessTime = 131_072,
ModifyMetadataWriteTime = 262_144,
ModifyMetadataPermissions = 524_288,
ModifyMetadataOwnership = 1_048_576,
ModifyMetadataExtended = 2_097_152,
ModifyMetadataOther = 4_194_304,
ModifyRename = 8_388_608,
ModifyRenameTo = 16_777_216,
ModifyRenameFrom = 33_554_432,
ModifyRenameBoth = 67_108_864,
ModifyRenameOther = 134_217_728,
ModifyOther = 268_435_456,
Delete = 536_870_912,
DeleteFile = 1_073_741_824,
DeleteFolder = 2_147_483_648,
DeleteOther = 4_294_967_296,
Other = 8_589_934_592,
}Variants
Established = 1
Synthetic event fired when a watch is first established.
This is not a filesystem event—it’s generated immediately when the watch is set up, regardless of whether the path exists. Useful for triggering an initial read of watched files.
Any = 2
Matches any event type.
Access = 4
AccessOpen = 8
AccessClose = 16
AccessRead = 32
AccessOther = 64
Create = 128
CreateFile = 256
CreateFolder = 512
CreateOther = 1_024
Modify = 2_048
ModifyData = 4_096
ModifyDataSize = 8_192
ModifyDataContent = 16_384
ModifyDataOther = 32_768
ModifyMetadata = 65_536
ModifyMetadataAccessTime = 131_072
ModifyMetadataWriteTime = 262_144
ModifyMetadataPermissions = 524_288
ModifyMetadataOwnership = 1_048_576
ModifyMetadataExtended = 2_097_152
ModifyMetadataOther = 4_194_304
ModifyRename = 8_388_608
ModifyRenameTo = 16_777_216
ModifyRenameFrom = 33_554_432
ModifyRenameBoth = 67_108_864
ModifyRenameOther = 134_217_728
ModifyOther = 268_435_456
Delete = 536_870_912
DeleteFile = 1_073_741_824
DeleteFolder = 2_147_483_648
DeleteOther = 4_294_967_296
Other = 8_589_934_592