pub struct Watched { /* private fields */ }Expand description
A watched path
The watch will be stopped when this object is dropped. This
object is essentially the Id, you can use this as a key in a
HashMap and look up the entry by Id
Implementations