WatcherConfigBuilder

Struct WatcherConfigBuilder 

pub struct WatcherConfigBuilder<T: EventHandler> { /* private fields */ }
Builder for WatcherConfig.

Implementations

Source

impl<T: EventHandler + Clone> WatcherConfigBuilder<T>

pub fn timeout(&mut self, value: Duration) -> &mut Self

The debounce timeout, events will not arrive faster than this. Default 250ms.

pub fn tick_rate(&mut self, value: Duration) -> &mut Self

How often the debouncer ticks. Default 1/4 of the timeout

pub fn poll_interval(&mut self, value: Duration) -> &mut Self

The poll interval determines how often to poll a batch of files. Polling is necessary to cover cases that filesystem notifications can’t handle, such as watching a path that doesn’t yet exist. Each poll interval, poll batch files will be checked in parallel.

The minimum poll interval is 100ms, an error will be returned if you try to set the value lower than that.

default 1 second

pub fn poll_batch(&mut self, value: usize) -> &mut Self

How many files to poll each poll interval. If this is set to 0 polling is disabled.

default 100

pub fn event_handler(&mut self, value: T) -> &mut Self

Where to send the events (required)

pub fn build(&self) -> Result<WatcherConfig<T>, WatcherConfigBuilderError>

Builds a new WatcherConfig.

Errors

If a required field has not been initialized.