pub struct WatcherConfigBuilder<T: EventHandler> { /* private fields */ }Expand description
Builder for WatcherConfig.
Implementations
Sourceimpl<T: EventHandler + Clone> WatcherConfigBuilder<T>
impl<T: EventHandler + Clone> WatcherConfigBuilder<T>
Sourcepub fn timeout(&mut self, value: Duration) -> &mut Self
pub fn timeout(&mut self, value: Duration) -> &mut Self
The debounce timeout, events will not arrive faster than this. Default 250ms.
Sourcepub fn tick_rate(&mut self, value: Duration) -> &mut Self
pub fn tick_rate(&mut self, value: Duration) -> &mut Self
How often the debouncer ticks. Default 1/4 of the timeout
Sourcepub fn poll_interval(&mut self, value: Duration) -> &mut Self
pub fn poll_interval(&mut self, value: Duration) -> &mut Self
The poll interval determines how often to poll a batch of files. Polling is necessary to cover cases that filesystem notifications can’t handle, such as watching a path that doesn’t yet exist. Each poll interval, poll batch files will be checked in parallel.
The minimum poll interval is 100ms, an error will be returned if you try to set the value lower than that.
default 1 second
Sourcepub fn poll_batch(&mut self, value: usize) -> &mut Self
pub fn poll_batch(&mut self, value: usize) -> &mut Self
How many files to poll each poll interval. If this is set to 0 polling is disabled.
default 100
Sourcepub fn event_handler(&mut self, value: T) -> &mut Self
pub fn event_handler(&mut self, value: T) -> &mut Self
Where to send the events (required)
Sourcepub fn build(&self) -> Result<WatcherConfig<T>, WatcherConfigBuilderError>
pub fn build(&self) -> Result<WatcherConfig<T>, WatcherConfigBuilderError>